Community
=========

LinchPin has a small, but vibrant community. Come help us while you learn a skill.

.. toctree::
    :maxdepth: 1

    mailing_list
    irc
    source_code
    documentation

.. include:: includes/footer.rst
